IMEst <-
function(x,y,z,xIndex=NA,zIndex=NA,nameNames=TRUE){
	# Multiplicative interaction phenotype model estimation y=b*x*z+e
	# Arguments:
	#	x : measured SNP encoded as {0,1,2}
	#	z : measured SNP encoded as {0,1,2}
	#	y : measured continuous phenotype 
	#	xIndex : optional index for the SNP x in the dataset
	#	zIndex : optional index for the SNP z in the dataset
	#	nameNames : optional naming for the entries of the output vector
	# Value:
	#	A vector of numerical values:
	#		regression (interaction) coefficient b
	#		variance of the noise e
	#		LD between the 2 SNPs
	#		MAF of SNP x
	#		MAF of SNP z
	#		standard error of the estimate b
	#		sample size
	#		p-value for the estimate using the t-test
	#		index of SNP x as given by xIndex
	#		index of SNP z as given by zIndex
	
	U<-x*z;
	nas<-!is.na(U);
	V<-y[nas];
	U<-U[nas];
	b<-cov(U,V)/var(U);
	n<-length(V);
	
	p<-mean(z,na.rm=T)/2;
	q<-mean(x,na.rm=T)/2;
	Dxz<-cov(x,z,use="complete")/2;
	
	
	VX<-var(U);
	sigma<-var(V)-b^2*VX;
	EX<-mean(U);
	
	VeX<-sigma*(VX+EX^2);
	ser<-sqrt(1/n*VeX)/VX;
	
	pValue<-2*pt(abs(b)/ser,n-1,lower.tail=F);
	out<-c(b,
		 sigma,
		 Dxz,
		 q,
		 p,
		 ser,
		 n,
		 pValue,
		 xIndex,
		 zIndex);
	if(nameNames){
		names(out)<-c("interaction",
		 	"sigma",
		 	"LD",
		 	"MAF1",
		 	"MAF2",
		 	"ser",
		 	"sample_size",
		 	"pValue",
		 	"SNP1Index",
		 	"SNP2Index");
	}
	return(out);
}
