LMEst <-
function(x,y,xIndex=NA,nameNames=TRUE){
	# Linear phenotype model estimation y=b*x+e
	# Arguments:
	#	x : measured SNP encoded as {0,1,2}
	#	y : measured continuous phenotype 
	#	xIndex : optional index for the SNP in the dataset
	#	nameNames : optional naming for the entries of the output vector
	# Value:
	#	A vector of numerical values:
	#		regression coefficient b
	#		variance of the noise e
	#		MAF of SNP x
	#		standard error of the estimate b
	#		p-value for the estimate using the t-test
	#		index of SNP x as given by xIndex
	
	nas<-!is.na(x);
	V<-y[nas];
	U<-x[nas];
	b<-cov(U,V)/var(U);
	n<-length(V);
	
	q<-mean(x,na.rm=T)/2;
	
	VX<-var(U);
	sigma<-var(V)-b^2*VX;
	EX<-mean(U);
	
	VeX<-sigma*(VX+EX^2);
	ser<-sqrt(1/n*VeX)/VX;
	
	pValue<-2*pt(abs(b)/ser,n-1,lower.tail=F);
	out<-c(b,
		 sigma,
		 q,
		 ser,
		 n,
		 pValue,
		 xIndex);
	if(nameNames){
		names(out)<-c("interaction",
		 	"sigma",
		 	"MAF",
		 	"ser",
		 	"sample_size",
		 	"pValue",
		 	"SNPIndex");
	}
	return(out);
}
