\name{LIMEpi-package}
\alias{LIMEpi-package}
\alias{LIMEpi}
\docType{package}
\title{
Latent Interaction Modelling for Epistasis detection
}
\description{
The package contains functions that implement a two-stage epistasis detection procedure from GWAS data, given a continuous phenotype. The first stage consists of a novel SNP ranking procedure according to the SNPs potential to interact with a latent SNP with respect to the phenotype.
}
\details{
\tabular{ll}{
Package: \tab LIMEpi\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2013-05-08\cr
License: \tab GPL-3 \cr
}
Given a SNP dataset and a continuous phenotype, run first \code{\link{inteRank}} to rank and select SNPs according to their interaction potential, then run \code{\link{secondStage}} to rank and select pairs of SNPs.
You may also run \code{\link{LIMEst}} on single SNPs.
}
\author{
Janos-Zsigmond Kelemen, Niko Beerenwinkel
Maintainer: Niko Beerenwinkel <niko.beerenwinkel@bsse.ethz.ch>
}
\references{
%% ~~ Literature or other references for background information ~~
}
%% ~~ Optionally other standard keywords, one ~~
%% ~~ per line, from file KEYWORDS in the R ~~
%% ~~ documentation directory ~~
\keyword{ package }
\seealso{
%% ~~ Optional links to other man pages, e.g. ~~
%% ~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~
}
\examples{
## Set a sample size
N <- 1000
## Set the MAF for the observed SNP
q <- 0.3
## Set the MAF for the unobserved SNP
p <- 0.3
## Simulate the observed SNP assuming HWE
x <- sample(c(0,1,2),N,replace=TRUE,prob=c((1-q)^2,2*q*(1-q),q^2))
## Simulate the unobserved SNP assuming HWE
z <- sample(c(0,1,2),N,replace=TRUE,prob=c((1-p)^2,2*p*(1-p),p^2))
## Simulate the phenotype a multiplicative phenotype and adding Gaussian noise
y <- x*z + rnorm(N,0,2)
## Run LIMEst with the observed SNP and the phenotype
LIMEst(x, y, xIndex = NA, nameNames = TRUE)
## Simulate the another observed SNP assuming HWE
x1 <- sample(c(0,1,2),N,replace=TRUE,prob=c((1-q)^2,2*q*(1-q),q^2))
## Run again LIMEst (compare p-values)
LIMEst(x1, y, xIndex = NA, nameNames = TRUE)
}
